@@ -17,14 +17,21 @@ public:
     explicit BitButton(QWidget *parent = nullptr);
     Q_REQUIRED_RESULT bool isOn() const;
     void setOn(bool value);
+    void setRenderSize(const QSize &size);
+    QSize renderSize() const;
 
 protected:
     void paintEvent(QPaintEvent *event) override;
 
 private:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *event) override;
+#else
     void enterEvent(QEvent *event) override;
+#endif
     void leaveEvent(QEvent *event) override;
     bool on_ = false;
     bool over_ = false;
+    QSize renderSize_;
 };
 
