@@ -106,6 +106,9 @@ public:
 
     Q_DECLARE_FLAGS(UpdateFlags, UpdateFlag)
 
+protected:
+    void resizeEvent(QResizeEvent* event) override;
+    
 private:
     bool eventFilter(QObject *o, QEvent *e) override;
     bool event(QEvent *e) override;
@@ -125,6 +128,13 @@ private:
     void setPrecision();
     void setAngle();
     void setBase();
+    
+    void setBaseFont(const QFont &font);
+    const QFont &baseFont() const;
+    bool isMinimumSize();
+    void forceResizeEvent();
+    void setLeftPadLayoutActive(bool active);
+    void setBitsetLayoutActive(bool active);
 
     void updateDisplay(UpdateFlags flags);
     void updateHistoryWithFunction(CalcEngine::Operation);
@@ -263,6 +273,9 @@ private:
     QList<QAbstractButton *> mem_button_list_;
     QList<QAbstractButton *> operation_button_list_;
 
+    QFont baseFont_;
+    bool is_still_in_launch_ = true; // necessary for startup at minimum size
+
     CalcEngine core;
 };
 
